package data.features.authorize

import data.features.model.UserDTO
import data.features.password.PasswordRepository
import data.features.password.PasswordRepositoryImpl
import domain.Request.AuthorizeRequest
import domain.Request.RegistrationRequest
import domain.Response.UserResponse
import io.github.serpro69.kfaker.Faker
import model.User
import java.util.*
import javax.crypto.SecretKeyFactory
import javax.crypto.spec.PBEKeySpec

private val passwordRepository = PasswordRepositoryImpl()
val users = generateUsers(100).toMutableList()

class AuthorizeRepositoryImpl: AuthorizeRepository {
    override fun auth(authorizeRequest: AuthorizeRequest): UserResponse {
        val userEmail = authorizeRequest.email
        val user = users.find { it.email == userEmail }
        require(user != null){
            "no user with that email"
        }

        val password = passwordRepository.hashedPassword(authorizeRequest.password, "salt".toByteArray())
        val authed = passwordRepository.matches(authorizeRequest.password, "salt".toByteArray(), user.password)
        if (authed){
            println("dodo")
        }else{
            println("nono")
        }
        return  UserResponse(user.firstName, user.lastName, user.email, user.number, user.address, user.photo)
    }

    override fun registration(request: RegistrationRequest): UserResponse {
        val newUser = UserDTO(uuid = UUID.randomUUID(), email = request.email, password = passwordRepository.hashedPassword(request.password, "salt".toByteArray()), firstName = request.firstName)
        users.add(newUser)
        return UserResponse(newUser.firstName, newUser.lastName, newUser.email, newUser.number, newUser.address, newUser.photo)
    }
}

fun generateUsers(userCount: Int): List<UserDTO>{
    val localUserList = mutableListOf<UserDTO>()
    val faker = Faker()
    repeat(userCount){
        localUserList.add(
            UserDTO(
                uuid = UUID.randomUUID(),
                firstName = faker.name.firstName(),
                lastName = faker.name.lastName(),
                email = faker.random.randomString(3)+"@mail.ru",
                password = passwordRepository.hashedPassword(faker.random.randomString(12), "salt".toByteArray()),
                number = faker.phoneNumber.phoneNumber(),
                address = faker.address.fullAddress(),
                photo = faker.file.toString()
            )
        )

    }
    return localUserList
}